# The PostDB main module
#
module PostDB
  class << self
    # Require dependencies
    #
    # Example:
    #   >> PostDB.require!
    #   => nil
    #
    def require!
      require 'cgi'
      require 'openssl'
      require 'fileutils'
      require 'active_support'
      require 'active_record'
      require 'attr_password'

      require 'postdb/constants'
      require 'postdb/errors'
      require 'postdb/helpers'
      require 'postdb/configuration'
      require 'postdb/database'
      require 'postdb/mail_location'
      require 'postdb/mail'
      require 'postdb/dkim'
      require 'postdb/domain'
      require 'postdb/user'
      require 'postdb/alias'
    end

    # Setup the gem
    #
    # Arguments:
    #   path: (String) The path to the configuration file
    #
    # Example:
    #   >> PostDB.setup(path)
    #   => true
    #
    def setup(path)
      PostDB::Configuration.load_file(path)

      PostDB::Database.setup_with_configuration!
      PostDB::Mail.setup_with_configuration!
      PostDB::DKIM.setup_with_configuration!

      true
    end
  end
end

# Require dependencies
#
PostDB.require!
