# The PostDB main module
#
module PostDB
  # The CLI module
  #
  module CLI
    class << self
      # Require dependencies
      #
      # Example:
      #   >> PostDB.require!
      #   => nil
      #
      def require!
        require 'yaml'
        require 'thor'
        require 'tty-prompt'
        require 'tty-table'
        require 'postdb'

        require 'postdb/cli/helper'
        require 'postdb/cli/database'
        require 'postdb/cli/domains/dkim'
        require 'postdb/cli/domains'
        require 'postdb/cli/users'
        require 'postdb/cli/aliases'
        require 'postdb/cli/main'
      end

      # Ensure superuser
      #
      # Example:
      #   >> PostDB::CLI.ensure_superuser!
      #   => nil
      #
      def ensure_superuser!
        return nil if 0 == Process.uid

        prompt = TTY::Prompt.new
        prompt.error("PostDB requires superuser privileges to run!")

        exit 1
      end
    end
  end
end

# Require dependencies
#
PostDB::CLI.require!

# Ensure superuser privileges
#
PostDB::CLI.ensure_superuser!
