module PostDB
  module CLI
    class Domains < Thor
      class DKIM < Thor
        no_tasks do
          include PostDB::CLI::Helper
        end

        desc "dns DOMAIN", "Get the DNS record for a domain's DKIM key"
        def dns(domain_name = nil)
          unless domain_name
            domains = PostDB::Domain.all

            if domains.empty?
              exit_with_warning("There don't appear to be any domains on this system.")
            end

            domain_name = prompt.select("Domain:", domains.map(&:name))
          end

          domain_name = domain_name.downcase

          domain = PostDB::Domain.where(name: domain_name).first

          dkim_public = [domain.dkim.public_key.to_der].pack('m').gsub("\n", '')

          puts "mail._domainkey.#{domain.name}:"
          puts " v=DKIM1; k=rsa; p=#{dkim_public};"
        end

        desc "regenerate DOMAIN", "Regenerate the DKIM key for a domain"
        option :force, type: :boolean, default: false
        def regenerate(domain_name = nil)
          unless domain_name
            domains = PostDB::Domain.all

            if domains.empty?
              exit_with_warning("There don't appear to be any domains on this system.")
            end

            domain_name = prompt.select("Domain:", domains.map(&:name))
          end

          domain_name = domain_name.downcase

          domains = PostDB::Domain.where(name: domain_name)

          if domains.empty?
            exit_with_warning("The domain '#{domain_name}' could not be found.")
          end

          unless options[:force]
            confirm_action!("Regenerate the DKIM key for '#{domain_name}'?", "'#{domain_name}' left untouched.")
          end

          domains.each do |domain|
            domain.regenerate_dkim

            unless domain.save
              exit_with_error("The DKIM key for '#{domain_name}' couldn't be regenerated.")
            end
          end

          prompt.ok("The DKIM key for '#{domain_name}' has been regenerated.")
        end
      end
    end
  end
end
