module PostDB
  module CLI
    # The main CLI class
    #
    # This class contains the core CLI functionality.
    #
    class Main < Thor
      class_option :configuration_file, type: :string, aliases: :c, default: '/etc/postdb/postdb.yml'
      class_option :verbose, type: :boolean, aliases: :v, default: false

      no_tasks do
        include PostDB::CLI::Helper

        def initialize(*args, &block)
          super(*args, &block)

          configuration_file = options[:configuration_file]

          unless File.file?(configuration_file)
            exit_with_error("The configuration file '#{configuration_file}' is missing.")
          end

          begin
            PostDB.setup(configuration_file)
          rescue PostDB::SetupError => e
            exit_with_error(e.message)
          end
        end
      end

      desc "domains SUBCOMMAND ...ARGS", "Manage the domains"
      subcommand "domains", PostDB::CLI::Domains

      desc "users SUBCOMMAND ...ARGS", "Manage the users"
      subcommand "users", PostDB::CLI::Users

      desc "aliases SUBCOMMAND ...ARGS", "Manage the aliases"
      subcommand "aliases", PostDB::CLI::Aliases

      desc "database SUBCOMMAND ...ARGS", "Manage the database"
      subcommand "database", PostDB::CLI::Database
    end
  end
end
