module PostDB
  # The MailLocationError error is used by the MailLocation class
  #
  class MailLocationError < StandardError
    # A suberror to describe the error in more detail
  	#
  	attr_reader :attribute

    # An array containing additional arguments
    #
    attr_reader :arguments

  	# Create a new instance of this exception
  	#
  	# Arguments:
  	#   suberror: (Symbol|String)
    #   args: (Array)
  	#
  	# Example:
  	#   >> raise PostDB::MailLocationError.new
  	#   => #<PostDB::MailLocationError:0x00000000000000>
  	#
  	def initialize(suberror = nil, *args)
  		# Store the suberror property (if provided)
  		@suberror = suberror if suberror

      # Store the arguments
      @arguments = args
  	end

    # Convert the error to a string
    #
    # Example:
    #   >> error.to_s
    #   => "Error Description"
    #
    def to_s
      case @suberror
      when :malformed_location
        "'#{@arguments[0]}' is not a valid location."
      else
        super.to_s
      end
    end
  end
end
