module OpenSSL
  module PKey
    class RSA
      class << self
        # Dump the object
        #
        # Arguments:
        #   object: (OpenSSL::PKey::RSA)
        #
        # Example:
        #   >> OpenSSL::PKey::RSA.dump(rsa)
        #   => "..."
        #
        def dump(object)
          unless object.is_a?(self)
            raise ActiveRecord::SerializationTypeMismatch, "Expected '#{self}' got '#{object.class}'."
          end

          object.to_der
        end

        # Load the object
        #
        # Arguments:
        #   object: (String)
        #
        # Example:
        #   >> OpenSSL::PKey::RSA.load(object)
        #   => #<OpenSSL::PKey::RSA:0x00000000000000>
        #
        def load(object)
          return nil unless object

          new(object)
        end
      end

      # Check if the RSA key is valid
      #
      # Example:
      #   >> key.valid?
      #   => true
      #
      def valid?
        begin
          self.class.new(self.to_der)
        rescue OpenSSL::PKey::RSAError => e
          return false
        end

        true
      end
    end
  end
end
