module PostDB
  class User < ActiveRecord::Base
    self.table_name = 'virtual_users'

    has_password :sha512

    has_one :alias, dependent: :destroy

    belongs_to :domain

    validates :email,            presence: true, uniqueness: true
    validates :crypted_password, presence: true

    before_save do |user|
      user.alias ||= PostDB::Alias.create(
        domain: user.domain,
        source: user.email,
        destination: user.email
      )
    end

    after_destroy do |user|
      user.delete_account_data
    end

    def delete_account_data
      mail_location = PostDB::Mail.mail_location

      path = mail_location.get_path(self.email, self.domain.name)

      return false unless File.exist?(path)

      begin
        FileUtils.rm_rf(path)
      rescue => e
        return false
      end

      true
    end
  end
end
